@@ -32,16 +32,16 @@ public class ReactNestedScrollViewHelper {
   /**
    * Shared by {@link ReactNestedScrollView} and {@link ReactHorizontalScrollView}.
    */
-  public static void emitScrollEvent(ViewGroup scrollView) {
-    emitScrollEvent(scrollView, ScrollEventType.SCROLL);
+  public static void emitScrollEvent(ViewGroup scrollView, float xVelocity, float yVelocity) {
+    emitScrollEvent(scrollView, ScrollEventType.SCROLL, xVelocity, yVelocity);
   }
 
   public static void emitScrollBeginDragEvent(ViewGroup scrollView) {
     emitScrollEvent(scrollView, ScrollEventType.BEGIN_DRAG);
   }
 
-  public static void emitScrollEndDragEvent(ViewGroup scrollView) {
-    emitScrollEvent(scrollView, ScrollEventType.END_DRAG);
+  public static void emitScrollEndDragEvent(ViewGroup scrollView, float xVelocity, float yVelocity) {
+    emitScrollEvent(scrollView, ScrollEventType.END_DRAG, xVelocity, yVelocity);
   }
 
   public static void emitScrollMomentumBeginEvent(ViewGroup scrollView) {
@@ -53,6 +53,14 @@ public class ReactNestedScrollViewHelper {
   }
 
   private static void emitScrollEvent(ViewGroup scrollView, ScrollEventType scrollEventType) {
+    emitScrollEvent(scrollView, scrollEventType, 0, 0);
+  }
+
+  private static void emitScrollEvent(
+      ViewGroup scrollView,
+      ScrollEventType scrollEventType,
+      float xVelocity,
+      float yVelocity) {
     View contentView = scrollView.getChildAt(0);
 
     if (contentView == null) {
@@ -66,6 +74,8 @@ public class ReactNestedScrollViewHelper {
             scrollEventType,
             scrollView.getScrollX(),
             scrollView.getScrollY(),
+            xVelocity,
+            yVelocity,
             contentView.getWidth(),
             contentView.getHeight(),
             scrollView.getWidth(),
